import * as i0 from '@angular/core';
import { Injectable, Component } from '@angular/core';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { trigger, transition, style, animate } from '@angular/animations';
import { Subject } from 'rxjs';

/**
 * Service for managing custom notifications in the application.
 * This service provides methods to show different types of notifications
 * (success, warning, error, info) and allows for customization of the notification options.
 */
class CustomNotificationService {
    constructor() {
        this.notificationSubject = new Subject();
        this.notification$ = this.notificationSubject.asObservable();
    }
    /**
     * Displays a notification with the specified message and options.
     * Clears any existing notifications before showing the new one.
     *
     * @param {string} message - The message to display in the notification.
     * @param {IOptions} [options=this.defaultOptions()] - The options for customizing the notification.
     */
    show(message, options = this.defaultOptions()) {
        this.clear();
        this.notificationSubject.next({
            message,
            options,
        });
    }
    /**
     * Displays a success notification.
     *
     * @param {string} message - The message to display in the success notification.
     * @param {IOptions} [options=this.defaultOptions()] - The options for customizing the success notification.
     */
    success(message, options = this.defaultOptions()) {
        options.type = 'success';
        options.title = options.title ?? 'Success';
        this.show(message, options);
    }
    /**
     * Displays a warning notification.
     *
     * @param {string} message - The message to display in the warning notification.
     * @param {IOptions} [options=this.defaultOptions()] - The options for customizing the warning notification.
     */
    warning(message, options = this.defaultOptions()) {
        options.type = 'warning';
        options.title = options.title ?? 'Warning';
        this.show(message, options);
    }
    /**
     * Displays an error notification.
     *
     * @param {string} message - The message to display in the error notification.
     * @param {IOptions} [options=this.defaultOptions()] - The options for customizing the error notification.
     */
    error(message, options = this.defaultOptions()) {
        options.type = 'error';
        options.title = options.title ?? 'Error';
        this.show(message, options);
    }
    /**
     * Displays an info notification.
     *
     * @param {string} message - The message to display in the info notification.
     * @param {IOptions} [options=this.defaultOptions()] - The options for customizing the info notification.
     */
    info(message, options = this.defaultOptions()) {
        options.type = 'info';
        options.title = options.title ?? 'Info';
        this.show(message, options);
    }
    /**
     * Clears any existing notifications.
     */
    clear() {
        const options = this.defaultOptions();
        return this.notificationSubject.next({ message: '', options });
    }
    /**
     * Provides default options for notifications.
     *
     * @returns {IOptions} - An object containing default values for type, title, duration, and position of notifications.
     */
    defaultOptions() {
        return {
            type: 'success',
            title: 'Success',
            duration: 5000,
            position: 'top-end',
            closeButton: true,
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomNotificationService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomNotificationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomNotificationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * Component for displaying custom notifications in the application.
 * This component subscribes to the notification service to receive
 * notifications and display them.
 */
class CustomNotificationComponent {
    constructor(service) {
        this.service = service;
        this.isVisible = false; // Flag to control visibility of the notification
        this.position = 'top-end'; // Position of the notification on the screen
        this.iconClasses = {
            'success': "fa fa-check-circle text-success",
            'warning': "fa fa-exclamation-circle text-warning",
            'error': "fa fa-times-circle text-danger",
            'info': "fa fa-info-circle text-info",
        };
        this.positionClasses = {
            'top-end': 'top-0 end-0',
            'top-start': 'top-0 start-0',
            'bottom-end': 'bottom-0 end-0',
            'bottom-start': 'bottom-0 start-0',
        };
    }
    ngOnInit() {
        this.service.notification$.subscribe(({ message: msg, options }) => {
            this.isVisible = true;
            this.message = msg;
            this.type = options.type || 'success';
            this.position = options.position || 'top-end';
            this.title = options.title;
            this.iconClass = this.iconClasses[this.type];
            this.positionClass = this.positionClasses[this.position];
            this.closeButton = options.closeButton ?? true;
            if (this.notificationTimeout) {
                clearTimeout(this.notificationTimeout);
            }
            // Set a timeout to automatically hide the notification after a specified duration
            this.notificationTimeout = setTimeout(() => {
                this.hide();
            }, options.duration || this.service.defaultOptions().duration);
        });
    }
    /**
     * Hides the notification.
     */
    hide() {
        this.isVisible = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomNotificationComponent, deps: [{ token: CustomNotificationService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CustomNotificationComponent, isStandalone: true, selector: "ngx-custom-notification", ngImport: i0, template: "<div class=\"card position-absolute m-3\" [ngClass]=\"positionClass\" *ngIf=\"isVisible\" @slideInOut>\n    <div class=\"card-body pt-2 px-3 pb-0\">\n        <div class=\"d-flex justify-content-between align-items-center\">\n            <div class=\"d-flex align-items-center\">\n                <span class=\"me-1\">\n                    <i class={{iconClass}}></i>\n                </span>\n                <h6 class=\"mb-0\"> {{ title }}</h6>\n            </div>\n            <button *ngIf=\"closeButton\" type=\"button\" class=\"btn btn-close btn-sm\" (click)=\"hide()\"></button>\n        </div>\n        <p class=\"m-2 mt-0\">\n            {{ message }}\n        </p>\n    </div>\n</div>", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: BrowserAnimationsModule }], animations: [
            trigger('slideInOut', [
                transition(':enter', [
                    style({ opacity: 0 }),
                    animate('300ms ease-in', style({ opacity: 1 }))
                ]),
                transition(':leave', [
                    animate('300ms ease-out', style({ opacity: 0 }))
                ])
            ])
        ] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomNotificationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-custom-notification', standalone: true, imports: [
                        CommonModule,
                        BrowserAnimationsModule,
                    ], animations: [
                        trigger('slideInOut', [
                            transition(':enter', [
                                style({ opacity: 0 }),
                                animate('300ms ease-in', style({ opacity: 1 }))
                            ]),
                            transition(':leave', [
                                animate('300ms ease-out', style({ opacity: 0 }))
                            ])
                        ])
                    ], template: "<div class=\"card position-absolute m-3\" [ngClass]=\"positionClass\" *ngIf=\"isVisible\" @slideInOut>\n    <div class=\"card-body pt-2 px-3 pb-0\">\n        <div class=\"d-flex justify-content-between align-items-center\">\n            <div class=\"d-flex align-items-center\">\n                <span class=\"me-1\">\n                    <i class={{iconClass}}></i>\n                </span>\n                <h6 class=\"mb-0\"> {{ title }}</h6>\n            </div>\n            <button *ngIf=\"closeButton\" type=\"button\" class=\"btn btn-close btn-sm\" (click)=\"hide()\"></button>\n        </div>\n        <p class=\"m-2 mt-0\">\n            {{ message }}\n        </p>\n    </div>\n</div>" }]
        }], ctorParameters: function () { return [{ type: CustomNotificationService }]; } });

/*
 * Public API Surface of ngx-custom-notification
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CustomNotificationComponent };
//# sourceMappingURL=ngx-custom-notification.mjs.map
